@@ -19,8 +19,9 @@ def download_blob(bucket_name, source_file, destination_file):
     storage_client = storage.Client()
     bucket = storage_client.get_bucket(bucket_name)
     blob = bucket.blob(source_file)
-    result = blob.download_as_string(destination_file)
-    return result
+    blob.download_to_filename(destination_file)
+
+    print('File {} downloaded to {}.'.format(source_file, destination_file))
 
 
 class _BatchingFn(DoFn):
@@ -62,44 +63,102 @@ class BatchingFn(PTransform):
 
 class _CreateCategoricalEncodedVariables(DoFn):
 
-
     def process(self, data):
+        from user_feature_utils.feature_creation_utils import LabelEncoderExt
         # Multi Label Binarizer Variables
         # Split out Equipment Types
 
-        equipment_mlb = pickle.load(download_blob("user_transforms", "user_equipment_mlb.pkl", "user_equipment_mlb.pkl"))
-        state_lbe = pickle.load(download_blob("user_transforms", "user_state_lbe.pkl", "user_state_lbe.pkl"))
-        state_ohe = pickle.load(download_blob("user_transforms", "user_state_ohe.pkl", "user_state_ohe.pkl"))
-        city_lbe = pickle.load(download_blob("user_transforms", "user_city_lbe.pkl", "user_city_lbe.pkl"))
-        city_ohe = pickle.load(download_blob("user_transforms", "user_city_ohe.pkl", "user_city_ohe.pkl"))
-        email_lbe = pickle.load(download_blob("user_transforms", "user_email_lbe.pkl", "user_email_lbe.pkl"))
-        email_ohe = pickle.load(download_blob("user_transforms", "user_email_ohe.pkl", "user_email_ohe.pkl"))
-        zip_code_lbe = pickle.load(download_blob("user_transforms", "user_zip_code_lbe.pkl", "user_zip_code_lbe.pkl"))
-        zip_code_ohe = pickle.load(download_blob("user_transforms", "user_zip_code_ohe.pkl", "user_zip_code_ohe.pkl"))
-        channel_lbe = pickle.load(download_blob("user_transforms", "user_channel_lbe.pkl", "user_channel_lbe.pkl"))
-        channel_ohe = pickle.load(download_blob("user_transforms", "user_channel_ohe.pkl", "user_channel_ohe.pkl"))
-        dot_lbe = pickle.load(download_blob("user_transforms", "user_dot_lbe.pkl", "user_dot_lbe.pkl"))
-        dot_ohe = pickle.load(download_blob("user_transforms", "user_dot_ohe.pkl", "user_dot_ohe.pkl"))
-        hos_home_timezone_lbe = pickle.load(
-            download_blob("user_transforms", "user_hos_home_timezone_lbe.pkl", "user_hos_home_timezone_lbe.pkl"))
-        hos_home_timezone_ohe = pickle.load(
-            download_blob("user_transforms", "user_hos_home_timezone_ohe.pkl", "user_hos_home_timezone_ohe.pkl"))
-        hos_cycle_lbe = pickle.load(
-            download_blob("user_transforms", "user_hos_cycle_lbe.pkl", "user_hos_cycle_lbe.pkl"))
-        hos_cycle_ohe = pickle.load(
-            download_blob("user_transforms", "user_hos_cycle_ohe.pkl", "user_hos_cycle_ohe.pkl"))
-        mc_number_lbe = pickle.load(
-            download_blob("user_transforms", "user_mc_number_lbe.pkl", "user_mc_number_lbe.pkl"))
-        mc_number_ohe = pickle.load(
-            download_blob("user_transforms", "user_mc_number_ohe.pkl", "user_mc_number_ohe.pkl"))
-        user_type_lbe = pickle.load(
-            download_blob("user_transforms", "user_user_type_lbe.pkl", "user_user_type_lbe.pkl"))
-        user_type_ohe = pickle.load(
-            download_blob("user_transforms", "user_user_type_ohe.pkl", "user_user_type_ohe.pkl"))
-        safety_rating_lbe = pickle.load(
-            download_blob("user_transforms", "user_safety_rating_lbe.pkl", "user_safety_rating_lbe.pkl"))
-        safety_rating_ohe = pickle.load(
-            download_blob("user_transforms", "user_safety_rating_ohe.pkl", "user_safety_rating_ohe.pkl"))
+        download_blob("user_transforms", "user_equipment_mlb.pkl", "user_equipment_mlb.pkl")
+        with open('user_equipment_mlb.pkl', 'rb') as f:
+            equipment_mlb = pickle.load(f)
+
+        download_blob("user_transforms", "user_state_lbe.pkl", "user_state_lbe.pkl")
+        with open('user_state_lbe.pkl', 'rb') as f:
+            state_lbe = pickle.load(f)
+
+        download_blob("user_transforms", "user_state_ohe.pkl", "user_state_ohe.pkl")
+        with open('user_state_ohe.pkl', 'rb') as f:
+            state_ohe = pickle.load(f)
+
+        download_blob("user_transforms", "user_city_lbe.pkl", "user_city_lbe.pkl")
+        with open('user_city_lbe.pkl', 'rb') as f:
+            city_lbe = pickle.load(f)
+
+        download_blob("user_transforms", "user_city_ohe.pkl", "user_city_ohe.pkl")
+        with open('user_city_ohe.pkl', 'rb') as f:
+            city_ohe = pickle.load(f)
+
+        download_blob("user_transforms", "user_email_lbe.pkl", "user_email_lbe.pkl")
+        with open('user_email_lbe.pkl', 'rb') as f:
+            email_lbe = pickle.load(f)
+
+        download_blob("user_transforms", "user_email_ohe.pkl", "user_email_ohe.pkl")
+        with open('user_email_ohe.pkl', 'rb') as f:
+            email_ohe = pickle.load(f)
+
+        download_blob("user_transforms", "user_zip_code_lbe.pkl", "user_zip_code_lbe.pkl")
+        with open('user_zip_code_lbe.pkl', 'rb') as f:
+            zip_code_lbe = pickle.load(f)
+
+        download_blob("user_transforms", "user_zip_code_ohe.pkl", "user_zip_code_ohe.pkl")
+        with open('user_zip_code_ohe.pkl', 'rb') as f:
+            zip_code_ohe = pickle.load(f)
+
+        download_blob("user_transforms", "user_channel_lbe.pkl", "user_channel_lbe.pkl")
+        with open('user_channel_lbe.pkl', 'rb') as f:
+            channel_lbe = pickle.load(f)
+
+        download_blob("user_transforms", "user_channel_ohe.pkl", "user_channel_ohe.pkl")
+        with open('user_channel_ohe.pkl', 'rb') as f:
+            channel_ohe = pickle.load(f)
+
+        download_blob("user_transforms", "user_dot_lbe.pkl", "user_dot_lbe.pkl")
+        with open('user_dot_lbe.pkl', 'rb') as f:
+            dot_lbe = pickle.load(f)
+
+        download_blob("user_transforms", "user_dot_ohe.pkl", "user_dot_ohe.pkl")
+        with open('user_dot_ohe.pkl', 'rb') as f:
+            dot_ohe = pickle.load(f)
+
+        download_blob("user_transforms", "user_hos_home_timezone_lbe.pkl", "user_hos_home_timezone_lbe.pkl")
+        with open('user_hos_home_timezone_lbe.pkl', 'rb') as f:
+            hos_home_timezone_lbe = pickle.load(f)
+
+        download_blob("user_transforms", "user_hos_home_timezone_ohe.pkl", "user_hos_home_timezone_ohe.pkl")
+        with open('user_hos_home_timezone_ohe.pkl', 'rb') as f:
+            hos_home_timezone_ohe = pickle.load(f)
+
+        download_blob("user_transforms", "user_hos_cycle_lbe.pkl", "user_hos_cycle_lbe.pkl")
+        with open('user_hos_cycle_lbe.pkl', 'rb') as f:
+            hos_cycle_lbe = pickle.load(f)
+
+        download_blob("user_transforms", "user_hos_cycle_ohe.pkl", "user_hos_cycle_ohe.pkl")
+        with open('user_hos_cycle_ohe.pkl', 'rb') as f:
+            hos_cycle_ohe = pickle.load(f)
+
+        download_blob("user_transforms", "user_mc_number_lbe.pkl", "user_mc_number_lbe.pkl")
+        with open('user_mc_number_lbe.pkl', 'rb') as f:
+            mc_number_lbe = pickle.load(f)
+
+        download_blob("user_transforms", "user_mc_number_ohe.pkl", "user_mc_number_ohe.pkl")
+        with open('user_mc_number_ohe.pkl', 'rb') as f:
+            mc_number_ohe = pickle.load(f)
+
+        download_blob("user_transforms", "user_type_lbe.pkl", "user_type_lbe.pkl")
+        with open('user_type_lbe.pkl', 'rb') as f:
+            user_type_lbe = pickle.load(f)
+
+        download_blob("user_transforms", "user_type_ohe.pkl", "user_type_ohe.pkl")
+        with open('user_type_ohe.pkl', 'rb') as f:
+            user_type_ohe = pickle.load(f)
+
+        download_blob("user_transforms", "user_safer_result_safety_rating_lbe.pkl", "user_safer_result_safety_rating_lbe.pkl")
+        with open('user_safer_result_safety_rating_lbe.pkl', 'rb') as f:
+            safety_rating_lbe = pickle.load(f)
+
+        download_blob("user_transforms", "user_safer_result_safety_rating_ohe.pkl", "user_safer_result_safety_rating_ohe.pkl")
+        with open('user_safer_result_safety_rating_ohe.pkl', 'rb') as f:
+            safety_rating_ohe = pickle.load(f)
 
         df = pd.DataFrame(data)
         df.equipment_types.fillna(value=u'', inplace=True)
@@ -390,13 +449,11 @@ class _CreateCategoricalEncodedVariables(DoFn):
 
         return [df, ]
 
-
 class CreateCategoricalEncodedVariables(PTransform):
 
     def expand(self, pcoll):
         return pcoll | ParDo(_CreateCategoricalEncodedVariables())
 
-
 class _SaveDataframeToGCS(DoFn):
 
     def process(self, df):
